Structs
- Agent
Response - Done
Message - Sent when the feed is exhausted or the run ends.
- Init
Message - Sent once at the start of an agent session.
- Shutdown
Message - Tick
Message - Sent each tick with current market state and engine snapshot.
Enums
- Agent
Action - A single action the agent wants to execute.
- Agent
Message - Response from the agent process.